//
// PDFsharp.Charting - A charting library based on PDFsharp
//
// Authors:
//   Niklas Schneider (mailto:Niklas.Schneider@pdfsharp.com)
//
// Copyright (c) 2005 empira Software GmbH, Cologne (Germany)
//
// http://www.pdfsharp.com
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

using System;
using PdfSharp.Drawing;

namespace PdfSharp.Charting.Renderers
{
  /// <summary>
  /// Represents a closed pie plot area renderer.
  /// </summary>
  internal class PieClosedPlotAreaRenderer : PiePlotAreaRenderer
	{
    /// <summary>
    /// Initializes a new instance of the PiePlotAreaRenderer class
    /// with the specified renderer parameters.
    /// </summary>
    internal PieClosedPlotAreaRenderer(RendererParameters parms) : base(parms)
		{
		}

    /// <summary>
    /// Calculate angles for each sector.
    /// </summary>
    protected override SectorDescription[] CalcSectors()
    {
      ChartRendererInfo cri = this.rendererParms.RendererInfo;
      if (cri.seriesRendererInfos.Length == 0)
        return null;

      SeriesRendererInfo sri = cri.seriesRendererInfos[0];

      double sumValues = 0;
      int sectorCount = 0;
      foreach (PointRendererInfo pri in sri.pointRendererInfos)
      {
        if (!double.IsNaN(pri.point.value))
        {
          sumValues += Math.Abs(pri.point.value);
          ++sectorCount;
        }
      }

      SectorDescription[] sectors = new SectorDescription[sectorCount];
      if (sectorCount == 0)
        return sectors;

      double startAngle = 270, sweepAngle = 0;
      int sectorIndex = 0;
      foreach (PointRendererInfo pri in sri.pointRendererInfos)
      {
        if (!double.IsNaN(pri.point.value))
        {
          sweepAngle = 360 / (sumValues / Math.Abs(pri.point.value));

          sectors[sectorIndex].rendererInfo = pri;
          sectors[sectorIndex].rect = cri.plotAreaRendererInfo.Rect;
          sectors[sectorIndex].startAngle = startAngle;
          sectors[sectorIndex].sweepAngle = sweepAngle;
          ++sectorIndex;

          startAngle += sweepAngle;
        }
      }

      return sectors;
    }
  }
}
